@@ -11,8 +11,6 @@ from tdxapi.models.asset_status_search import AssetStatusSearch
 
 @attr.s
 class AssetStatusManager(TdxManager, TdxAppMixin):
-    __tdx_section__ = "AssetStatuses"
-
     @tdx_method("GET", "/api/{appId}/assets/statuses/{id}")
     def get(self, asset_status_id: int) -> AssetStatus:
         """Gets an asset status."""
@@ -69,7 +67,7 @@ class AssetStatusManager(TdxManager, TdxAppMixin):
         helpers.save_model(asset_status, self, force)
 
     @tdx_method("POST", "/api/{appId}/assets/statuses")
-    def _insert(self, asset_status):
+    def _insert(self, asset_status: AssetStatus) -> AssetStatus:
         """Creates a new asset status."""
         return self.dispatcher.send(
             self._insert.method,
@@ -81,7 +79,7 @@ class AssetStatusManager(TdxManager, TdxAppMixin):
         )
 
     @tdx_method("PUT", "/api/{appId}/assets/statuses/{id}")
-    def _update(self, asset_status):
+    def _update(self, asset_status: AssetStatus) -> AssetStatus:
         """Edits an existing asset status."""
         return self.dispatcher.send(
             self._update.method,
