@@ -11,8 +11,6 @@ from tdxapi.models.configuration_item_type_search import ConfigurationItemTypeSe
 
 @attr.s
 class ConfigurationItemTypeManager(TdxManager, TdxAppMixin):
-    __tdx_section__ = "ConfigurationItemTypes"
-
     @tdx_method("GET", "/api/{appId}/cmdb/types/{id}")
     def get(self, configuration_item_type_id: int) -> ConfigurationItemType:
         """Gets a configuration item type."""
@@ -83,7 +81,9 @@ class ConfigurationItemTypeManager(TdxManager, TdxAppMixin):
         helpers.save_model(configuration_item_type, self, force)
 
     @tdx_method("POST", "/api/{appId}/cmdb/types")
-    def _insert(self, configuration_item_type):
+    def _insert(
+        self, configuration_item_type: ConfigurationItemType
+    ) -> ConfigurationItemType:
         """Creates a configuration item type."""
         return self.dispatcher.send(
             self._insert.method,
@@ -95,7 +95,9 @@ class ConfigurationItemTypeManager(TdxManager, TdxAppMixin):
         )
 
     @tdx_method("PUT", "/api/{appId}/cmdb/types/{id}")
-    def _update(self, configuration_item_type):
+    def _update(
+        self, configuration_item_type: ConfigurationItemType
+    ) -> ConfigurationItemType:
         """Edits an existing configuration item type."""
         return self.dispatcher.send(
             self._update.method,
