@@ -12,7 +12,6 @@ from tdxapi.models.product_model_search import ProductModelSearch
 
 @attr.s
 class ProductModelManager(TdxManager, TdxAppMixin, TdxCustomAttributeMixin):
-    __tdx_section__ = "ProductModels"
     __tdx_component__ = Component.PRODUCT_MODEL
 
     @tdx_method("GET", "/api/{appId}/assets/models/{id}")
@@ -81,7 +80,7 @@ class ProductModelManager(TdxManager, TdxAppMixin, TdxCustomAttributeMixin):
         helpers.save_model(product_model, self, force)
 
     @tdx_method("POST", "/api/{appId}/assets/models")
-    def _insert(self, product_model):
+    def _insert(self, product_model: ProductModel) -> ProductModel:
         """Creates a new product model."""
         return self.dispatcher.send(
             self._insert.method,
@@ -93,7 +92,7 @@ class ProductModelManager(TdxManager, TdxAppMixin, TdxCustomAttributeMixin):
         )
 
     @tdx_method("PUT", "/api/{appId}/assets/models/{id}")
-    def _update(self, product_model):
+    def _update(self, product_model: ProductModel) -> ProductModel:
         """Edits the specified product model."""
         return self.dispatcher.send(
             self._update.method,
