@@ -7,7 +7,7 @@ from dateutil.utils import default_tzinfo
 
 def to_datetime(value):
     """Convert TDX datetime string to Python DateTime."""
-    if value is None or value == "0001-01-01T05:00:00Z":
+    if value is None or value[:4] == "0001":
         return None
 
     if isinstance(value, str):
